from setuptools import setup
setup(name="mwhelper",
      version="0.7",
      py_modules=["mwhelper"],
      install_requires=['typing;python_version<="2.7"',
                        'EdpHelper==0.20'],
      url="http://www.e-deploy.com.br",
      author="Eduardo Almeida",
      author_email="eduardo.almeida@e-deploy.com.br"
)
